@@ -198,7 +198,7 @@ def get_dataset(
             created_at=parse_datetime(response.json().get("CreateDate")),
             updated_at=parse_datetime(response.json().get("UpdateDate")),
         )
-
+    print(response.text)
     response.raise_for_status()
     return None
 
@@ -335,9 +335,9 @@ def _upload_file(
         if isinstance(path_or_fileobj, (str, Path)):
             # s3 大小限制，使用multipart上传。
             # https://docs.aws.amazon.com/AmazonS3/latest/userguide/qfacts.html
-            multipart_config = TransferConfig(multipart_chunksize=1024 * 1024)
+            multipart_config = TransferConfig(multipart_chunksize=5 * 1024 * 1024)
             s3.upload_file(
-                path_or_fileobj,bucket_name, object_key,Config=multipart_config
+                path_or_fileobj, bucket_name, object_key, Config=multipart_config
             )
         else:
             s3.put_object(Bucket=bucket_name, Key=object_key, Body=path_or_fileobj)
@@ -373,7 +373,7 @@ def upload_file(
         raise ValueError("Failed to get upload token.")
     object_key = _upload_file(path_or_fileobj, path_in_dataset, upload_info)
     new_dataset_files: List[DatasetFile] = []
-    dataset = get_dataset(dataset_id, token)
+    dataset = get_dataset(dataset_id, token=token)
     if dataset is not None:
         for file in dataset.files:
             if file.path_in_dataset() != path_in_dataset:
@@ -447,7 +447,7 @@ def upload_folder(
     if upload_info is None:
         raise ValueError("Failed to get upload token.")
     new_dataset_files: Set[DatasetFile] = set()
-    dataset = get_dataset(dataset_id, token)
+    dataset = get_dataset(dataset_id, token=token)
     if dataset is None:
         raise ValueError(f"Dataset '{dataset_id}' not found.")
 
@@ -650,7 +650,7 @@ def download_dir(
     """
     token = _init_token(token)
     cache_dir = _init_cache(cache_dir)
-    dataset_detail = get_dataset(dataset_id)
+    dataset_detail = get_dataset(dataset_id, token=token)
     if dataset_detail is None:
         raise ValueError(f"Dataset '{dataset_id}' not found.")
     path_to_key: Dict[str, str] = dict()
@@ -772,7 +772,7 @@ def download_file(
     """
     token = _init_token(token)
     cache_dir = _init_cache(cache_dir)
-    dataset_detail = get_dataset(dataset_id)
+    dataset_detail = get_dataset(dataset_id, token=token)
     if dataset_detail is None:
         raise ValueError(f"Dataset '{dataset_id}' not found.")
     path_to_key: Dict[str, str] = dict()
@@ -878,7 +878,7 @@ def delete_file(
 ):
     """Delete a file from the dataset."""
     token = _init_token(token)
-    dataset = get_dataset(dataset_id, token)
+    dataset = get_dataset(dataset_id, token=token)
     if dataset is None:
         raise ValueError(f"Dataset '{dataset_id}' not found.")
     upload_info = _get_update_token(token)
@@ -918,11 +918,11 @@ def create_commit(
     upload_info = _get_update_token(token)
     if upload_info is None:
         raise ValueError("Failed to get upload token.")
-    dataset = get_dataset(dataset_id, token)
+    dataset = get_dataset(dataset_id, token=token)
     if dataset is None:
         raise ValueError(f"Dataset '{dataset_id}' not found.")
     _update_dataset(dataset_id, dataset.files, commit_message, token)
-    dataset = get_dataset(dataset_id, token)
+    dataset = get_dataset(dataset_id, token=token)
     if dataset is None:
         raise ValueError(f"Dataset '{dataset_id}' not found.")
     return dataset.commits[-1]
